@@ -32,18 +32,15 @@ class Context {
 }
 
 function getContext(node: SyntaxNode, doc: Text) {
-  let nodes = []
-  for (let cur: SyntaxNode | null = node; cur && cur.name != "Document"; cur = cur.parent) {
-    if (cur.name == "ListItem" || cur.name == "Blockquote" || cur.name == "FencedCode")
-      nodes.push(cur)
+  let nodes: SyntaxNode[] = [], context: Context[] = []
+  for (let cur: SyntaxNode | null = node; cur; cur = cur.parent) {
+    if (cur.name == "FencedCode") return context
+    if (cur.name == "ListItem" || cur.name == "Blockquote") nodes.push(cur)
   }
-  let context = []
   for (let i = nodes.length - 1; i >= 0; i--) {
     let node = nodes[i], match
     let line = doc.lineAt(node.from), startPos = node.from - line.from
-    if (node.name == "FencedCode") {
-      context.push(new Context(node, startPos, startPos, "", "", "", null))
-    } else if (node.name == "Blockquote" && (match = /^ *>( ?)/.exec(line.text.slice(startPos)))) {
+    if (node.name == "Blockquote" && (match = /^ *>( ?)/.exec(line.text.slice(startPos)))) {
       context.push(new Context(node, startPos, startPos + match[0].length, "", match[1], ">", null))
     } else if (node.name == "ListItem" && node.parent!.name == "OrderedList" &&
                (match = /^( *)\d+([.)])( *)/.exec(line.text.slice(startPos)))) {
@@ -107,7 +104,8 @@ function normalizeIndent(content: string, state: EditorState) {
 export const insertNewlineContinueMarkup: StateCommand = ({state, dispatch}) => {
   let tree = syntaxTree(state), {doc} = state
   let dont = null, changes = state.changeByRange(range => {
-    if (!range.empty || !markdownLanguage.isActiveAt(state, range.from)) return dont = {range}
+    if (!range.empty || !markdownLanguage.isActiveAt(state, range.from, -1) && !markdownLanguage.isActiveAt(state, range.from, 1))
+      return dont = {range}
     let pos = range.from, line = doc.lineAt(pos)
     let context = getContext(tree.resolveInner(pos, -1), doc)
     while (context.length && context[context.length - 1].from > pos - line.from) context.pop()
@@ -190,7 +188,9 @@ function nonTightList(node: SyntaxNode, doc: Text) {
 function blankLine(context: Context[], state: EditorState, line: Line) {
   let insert = ""
   for (let i = 0, e = context.length - 2; i <= e; i++) {
-    insert += context[i].blank(i < e ? countColumn(line.text, 4, context[i + 1].from) - insert.length : null, i < e)
+    insert += context[i].blank(i < e
+      ? countColumn(line.text, 4, context[i + 1].from) - insert.length
+      : null, i < e)
   }
   return normalizeIndent(insert, state)
 }
